@@ -114,11 +114,6 @@
   */
 #include <smtp.h>
 
- /* Duplicated to minimze patch footprint. */
-#define DELIVERY_REQUIRES_SMTPUTF8(request) \
-	((request->smtputf8 & SMTPUTF8_FLAG_REQUESTED) \
-	&& (request->smtputf8 & ~SMTPUTF8_FLAG_REQUESTED))
-
  /*
   * We use a configurable field terminator and optional place holder for data
   * that is unavailable or inapplicable. We base64-encode content that
