@@ -6,10 +6,10 @@
 /* SYNOPSIS
 /*	#include <iostuff.h>
 /*
-/*	int	dummy_read(fd, buf, buf_len, timeout, context)
+/*	ssize_t	dummy_read(fd, buf, buf_len, timeout, context)
 /*	int	fd;
 /*	void	*buf;
-/*	unsigned len;
+/*	size_t	len;
 /*	int	timeout;
 /*	void	*context;
 /* DESCRIPTION
@@ -17,8 +17,8 @@
 /*
 /*	Arguments:
 /* .IP fd
-/*	File descriptor in the range 0..FD_SETSIZE. Its value is logged
-/*	when verbose logging is turned on.
+/*	File descriptor whose value is logged when verbose logging
+/*	is turned on.
 /* .IP buf
 /*	Read buffer pointer. Not used.
 /* .IP buf_len
@@ -52,10 +52,10 @@
 
 /* dummy_read - dummy read operation */
 
-int     dummy_read(int fd, void *unused_buf, unsigned len,
+ssize_t dummy_read(int fd, void *unused_buf, size_t len,
 		           int unused_timeout, void *unused_context)
 {
     if (msg_verbose)
-	msg_info("dummy_read: fd %d, len %d", fd, len);
+	msg_info("dummy_read: fd %d, len %lu", fd, (unsigned long) len);
     return (0);
 }
